AndroidNotificationSettings class

Constructors

AndroidNotificationSettings({String notificationChannelName = 'Location tracking', String notificationTitle = 'Start Location Tracking', String notificationMsg = 'Track location in background', String notificationBigMsg = 'Background location is on to keep the app up-tp-date with your location. This is required for main features to work properly when the app is not running.', String notificationIcon = '', Color notificationIconColor = Colors.grey, VoidCallback? notificationTapCallback})
notificationTitle Title of the notification. Only applies for android. Default is 'Start Location Tracking'.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationBigMsg → String
final
notificationChannelName → String
final
notificationIcon → String
final
notificationIconColor → Color
final
notificationMsg → String
final
notificationTapCallback → VoidCallback?
final
notificationTitle → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited