IOSSettings class

Inheritance

Constructors

IOSSettings({LocationAccuracy accuracy = LocationAccuracy.NAVIGATION, double distanceFilter = 0, bool showsBackgroundLocationIndicator = false})
const

Properties

accuracy → LocationAccuracy
finalinherited
distanceFilter → double
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showsBackgroundLocationIndicator → bool
accuracy The accuracy of location, Default is max accuracy NAVIGATION.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited